==> jc-1.4.0.tar.gz: soot/grimp/PrecedenceTest.h <==
// public class soot.grimp.PrecedenceTest

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 62024d1de338216a soot_grimp_PrecedenceTest

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_grimp_PrecedenceTest_H_
#define _JC_soot_grimp_PrecedenceTest_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_grimp_PrecedenceTest$sub_refs	_jc_soot_grimp_PrecedenceTest$sub_refs;
typedef struct _jc_soot_grimp_PrecedenceTest$sub_nonrefs	_jc_soot_grimp_PrecedenceTest$sub_nonrefs;
typedef struct _jc_soot_grimp_PrecedenceTest$refs	_jc_soot_grimp_PrecedenceTest$refs;
typedef struct _jc_soot_grimp_PrecedenceTest$nonrefs	_jc_soot_grimp_PrecedenceTest$nonrefs;
typedef struct _jc_soot_grimp_PrecedenceTest$object	_jc_soot_grimp_PrecedenceTest$object;

typedef const struct _jc_soot_grimp_PrecedenceTest$vmethods	_jc_soot_grimp_PrecedenceTest$vmethods;
typedef const struct _jc_soot_grimp_PrecedenceTest$vtable	_jc_soot_grimp_PrecedenceTest$vtable;
typedef const struct _jc_soot_grimp_PrecedenceTest$vtype	_jc_soot_grimp_PrecedenceTest$vtype;

// Constructors
extern void _jc_soot_grimp_PrecedenceTest$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_grimp_PrecedenceTest$object *);

// Static methods
extern jboolean _jc_soot_grimp_PrecedenceTest$method$needsBrackets$1ab2203940554dbf(_jc_env *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_soot_grimp_PrecedenceTest$method$needsBracketsRight$4d5bff97bb4fa2f3(_jc_env *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_grimp_PrecedenceTest$vmethods {
};

// Vtable
struct _jc_soot_grimp_PrecedenceTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_grimp_PrecedenceTest$vmethods	soot_grimp_PrecedenceTest;
};

// Vtype
struct _jc_soot_grimp_PrecedenceTest$vtype {
	_jc_type			type;
	_jc_soot_grimp_PrecedenceTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_PrecedenceTest$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_PrecedenceTest$refs {
    _jc_soot_grimp_PrecedenceTest$sub_refs	soot_grimp_PrecedenceTest;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_PrecedenceTest$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_PrecedenceTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_grimp_PrecedenceTest$sub_nonrefs	soot_grimp_PrecedenceTest;
};

// Object instance structure
struct _jc_soot_grimp_PrecedenceTest$object {
	_jc_soot_grimp_PrecedenceTest$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_PrecedenceTest$vtype	*vtype;
	_jc_soot_grimp_PrecedenceTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_PrecedenceTest$vtype _jc_soot_grimp_PrecedenceTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_PrecedenceTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_PrecedenceTest$class_object;

#endif	/* _JC_soot_grimp_PrecedenceTest_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/PrecedenceTest.h <==
// public class soot.grimp.PrecedenceTest

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 62024d1de338216a soot_grimp_PrecedenceTest

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_grimp_PrecedenceTest_H_
#define _JC_soot_grimp_PrecedenceTest_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_grimp_PrecedenceTest$sub_refs	_jc_soot_grimp_PrecedenceTest$sub_refs;
typedef struct _jc_soot_grimp_PrecedenceTest$sub_nonrefs	_jc_soot_grimp_PrecedenceTest$sub_nonrefs;
typedef struct _jc_soot_grimp_PrecedenceTest$refs	_jc_soot_grimp_PrecedenceTest$refs;
typedef struct _jc_soot_grimp_PrecedenceTest$nonrefs	_jc_soot_grimp_PrecedenceTest$nonrefs;
typedef struct _jc_soot_grimp_PrecedenceTest$object	_jc_soot_grimp_PrecedenceTest$object;

typedef const struct _jc_soot_grimp_PrecedenceTest$vmethods	_jc_soot_grimp_PrecedenceTest$vmethods;
typedef const struct _jc_soot_grimp_PrecedenceTest$vtable	_jc_soot_grimp_PrecedenceTest$vtable;
typedef const struct _jc_soot_grimp_PrecedenceTest$vtype	_jc_soot_grimp_PrecedenceTest$vtype;

// Constructors
extern void _jc_soot_grimp_PrecedenceTest$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_grimp_PrecedenceTest$object *) _JC_JCNI_ATTR;

// Static methods
extern jboolean _jc_soot_grimp_PrecedenceTest$method$needsBrackets$1ab2203940554dbf(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_grimp_PrecedenceTest$method$needsBracketsRight$4d5bff97bb4fa2f3(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_grimp_PrecedenceTest$vmethods {
};

// Vtable
struct _jc_soot_grimp_PrecedenceTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_grimp_PrecedenceTest$vmethods	soot_grimp_PrecedenceTest;
};

// Vtype
struct _jc_soot_grimp_PrecedenceTest$vtype {
	_jc_type			type;
	_jc_soot_grimp_PrecedenceTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_PrecedenceTest$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_PrecedenceTest$refs {
    _jc_soot_grimp_PrecedenceTest$sub_refs	soot_grimp_PrecedenceTest;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_PrecedenceTest$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_PrecedenceTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_grimp_PrecedenceTest$sub_nonrefs	soot_grimp_PrecedenceTest;
};

// Object instance structure
struct _jc_soot_grimp_PrecedenceTest$object {
	_jc_soot_grimp_PrecedenceTest$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_PrecedenceTest$vtype	*vtype;
	_jc_soot_grimp_PrecedenceTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_PrecedenceTest$vtype _jc_soot_grimp_PrecedenceTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_PrecedenceTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_PrecedenceTest$class_object;

#endif	/* _JC_soot_grimp_PrecedenceTest_H_ */
